@@ -2,7 +2,7 @@
 #'
 #' Function returning data frame of LAU2 administrative units for the Czech Republic as \code{sf} points. It takes no parameters.
 #'
-#'  Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 270 KB.
+#' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 270 KB.
 #'
 #' @format \code{sf} data frame with 6.258 rows of 14 variables + geometry
 #'
@@ -24,12 +24,12 @@
 #'   }
 #'
 #'
-#' @source \url{https://www.arcdata.cz/produkty/geograficka-data/arccr-500}
+#' @source \url{https://vdp.cuzk.cz/}
 #'
 #'
 #' @export
 
 obce_body <- function() {
-  result <- downloader("ObceB.rds")
+  result <- downloader("ObceB-R.rds")
   result
 }
