@@ -23,15 +23,16 @@ expect_equal(nrow(republika()), 1)
 expect_equal(nrow(republika("low")), 1)
 expect_equal(nrow(republika("high")), 1)
 
-expect_equal(st_crs(republika("low"))$epsg, 4326)
-expect_equal(st_crs(republika("high"))$epsg, 4326)
+expect_equal(st_crs(republika("low"))$input, "EPSG:4326")
+expect_equal(st_crs(republika("high"))$input, "EPSG:4326")
 
+# sloupce se nerozbily...
+expect_equal(colnames(republika()), c("NAZ_STAT", "GeneralizovaneHranice"))
 
 expect_error(republika("bflm")) # neznámé rozlišení - očekávám high(default) / low
-expect_true(object.size(republika("low")) < object.size(republika("high")))
+
 # low res je menší než high res
-
-
+expect_true(object.size(republika("low")) < object.size(republika("high")))
 
 context("kraje")
 
@@ -55,13 +56,25 @@ expect_equal(nrow(kraje()), 14)
 expect_equal(nrow(kraje("low")), 14)
 expect_equal(nrow(kraje("high")), 14)
 
-expect_equal(st_crs(kraje("low"))$epsg, 4326)
-expect_equal(st_crs(kraje("high"))$epsg, 4326)
+expect_equal(st_crs(kraje("low"))$input, "EPSG:4326")
+expect_equal(st_crs(kraje("high"))$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(kraje()), c("KOD_KRAJ", "KOD_CZNUTS3", "NAZ_CZNUTS3", "GeneralizovaneHranice"))
 
 expect_error(kraje("bflm")) # neznámé rozlišení - očekávám high(default) / low
-expect_true(object.size(kraje("low")) < object.size(kraje("high")))
-# low res je menší než high res
 
+# low res je menší než high res
+expect_true(object.size(kraje("low")) < object.size(kraje("high")))
+
+# Středočeský kraj má v sobě díru jménem Praha - plocha je plus mínus 5%
+stc_low <- kraje("low") %>%
+  subset(KOD_CZNUTS3 == "CZ020")
+
+stc_high <- kraje("high") %>%
+  subset(KOD_CZNUTS3 == "CZ020")
+
+expect_equal(st_area(stc_low), st_area(stc_high), tolerance = 5/100)
 
 
 context("okresy")
@@ -86,12 +99,17 @@ expect_equal(nrow(okresy()), 77)
 expect_equal(nrow(okresy("low")), 77)
 expect_equal(nrow(okresy("high")), 77)
 
-expect_equal(st_crs(okresy("low"))$epsg, 4326)
-expect_equal(st_crs(okresy("high"))$epsg, 4326)
+expect_equal(st_crs(okresy("low"))$input, "EPSG:4326")
+expect_equal(st_crs(okresy("high"))$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(okresy()), c("KOD_OKRES", "KOD_LAU1", "NAZ_LAU1", "KOD_KRAJ",
+                                   "KOD_CZNUTS3", "NAZ_CZNUTS3", "GeneralizovaneHranice"))
 
 expect_error(okresy("bflm")) # neznámé rozlišení - očekávám high(default) / low
 
-expect_true(object.size(okresy("low")) < object.size(okresy("high"))) # low res je menší než high res
+# low res je menší než high res
+expect_true(object.size(okresy("low")) < object.size(okresy("high")))
 
 context("ORP")
 
@@ -109,7 +127,13 @@ expect_s3_class(orp_polygony(), "sf")
 
 expect_equal(nrow(orp_polygony()), 206)
 
-expect_equal(st_crs(orp_polygony())$epsg, 4326)
+expect_equal(st_crs(orp_polygony())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(orp_polygony()), c("KOD_ORP", "NAZ_ZKR_ORP", "NAZ_ORP", "KOD_RUIAN",
+                                         "KOD_OKRES", "KOD_LAU1", "NAZ_LAU1", "KOD_KRAJ",
+                                         "KOD_CZNUTS3", "NAZ_CZNUTS3", "GeneralizovaneHranice"))
+
 
 context("obce body")
 
@@ -127,7 +151,13 @@ expect_s3_class(obce_body(), "sf")
 
 expect_equal(nrow(obce_body()), 6258)
 
-expect_equal(st_crs(obce_body())$epsg, 4326)
+expect_equal(st_crs(obce_body())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(obce_body()), c("KOD_OBEC", "NAZ_OBEC", "KOD_ZUJ", "NAZ_ZUJ", "KOD_POU", "NAZ_POU",
+                                         "KOD_ORP", "NAZ_ORP", "KOD_OKRES", "KOD_LAU1", "NAZ_LAU1",
+                                         "KOD_KRAJ", "KOD_CZNUTS3", "NAZ_CZNUTS3", "DefinicniBod"))
+
 
 context("obce polygony")
 
@@ -145,7 +175,13 @@ expect_s3_class(obce_polygony(), "sf")
 
 expect_equal(nrow(obce_polygony()), 6258)
 
-expect_equal(st_crs(obce_polygony())$epsg, 4326)
+expect_equal(st_crs(obce_polygony())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(obce_polygony()), c("KOD_OBEC", "NAZ_OBEC", "KOD_ZUJ", "NAZ_ZUJ", "KOD_POU", "NAZ_POU",
+                                      "KOD_ORP", "NAZ_ORP", "KOD_OKRES", "KOD_LAU1", "NAZ_LAU1",
+                                      "KOD_KRAJ", "KOD_CZNUTS3", "NAZ_CZNUTS3", "GeneralizovaneHranice"))
+
 
 context("městské části")
 
@@ -163,7 +199,11 @@ expect_s3_class(casti(), "sf")
 
 expect_equal(nrow(casti()), 142)
 
-expect_equal(st_crs(casti())$epsg, 4326)
+expect_equal(st_crs(casti())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(casti()), c("KOD", "NAZEV", "KOD_OBEC", "NAZ_OBEC", "geometry"))
+
 
 context("vodní plochy")
 
@@ -181,7 +221,11 @@ expect_s3_class(plochy(), "sf")
 
 expect_equal(nrow(plochy()), 480)
 
-expect_equal(st_crs(plochy())$epsg, 4326)
+expect_equal(st_crs(plochy())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(plochy()), c("TYP", "NAZEV", "NAZEV_ASCII", "VYSKA", "geometry", "Major"))
+
 
 context("řeky")
 
@@ -193,13 +237,33 @@ Sys.setenv("AWS_UP" = FALSE)
 expect_message(reky(), "source") # zpráva o spadlém AWS
 Sys.setenv("AWS_UP" = TRUE)
 
+expect_error(reky(NA)) # parametr je povinný
+expect_error(reky("bflm")) # neznámý scope
+expect_error(reky(c("Praha", "Brno"))) # moc řek...
+
 expect_true(is.data.frame(reky()))
+expect_true(is.data.frame(reky("global")))
+expect_true(is.data.frame(reky("Praha")))
+expect_true(is.data.frame(reky("Brno")))
 
 expect_s3_class(reky(), "sf")
+expect_s3_class(reky("global"), "sf")
+expect_s3_class(reky("Praha"), "sf")
+expect_s3_class(reky("Brno"), "sf")
 
 expect_equal(nrow(reky()), 6198)
+expect_equal(nrow(reky("global")), 6198)
+expect_equal(nrow(reky("Praha")), 1)
+expect_equal(nrow(reky("Brno")), 2)
+
+expect_equal(st_crs(reky())$input, "EPSG:4326")
+expect_equal(st_crs(reky("global"))$input, "EPSG:4326")
+expect_equal(st_crs(reky("Praha"))$input, "EPSG:4326")
+expect_equal(st_crs(reky("Brno"))$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(reky()), c("TYP", "NAZEV", "NAZEV_ASCII", "geometry", "Major"))
 
-expect_equal(st_crs(reky())$epsg, 4326)
 
 context("silnice")
 
@@ -217,7 +281,11 @@ expect_s3_class(silnice(), "sf")
 
 expect_equal(nrow(silnice()), 18979)
 
-expect_equal(st_crs(silnice())$epsg, 4326)
+expect_equal(st_crs(silnice())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(silnice()), c("TRIDA", "CISLO_SILNICE", "MEZINARODNI_OZNACENI", "geometry"))
+
 
 context("železnice")
 
@@ -235,7 +303,11 @@ expect_s3_class(zeleznice(), "sf")
 
 expect_equal(nrow(zeleznice()), 3525)
 
-expect_equal(st_crs(zeleznice())$epsg, 4326)
+expect_equal(st_crs(zeleznice())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(zeleznice()), c("ELEKTRIFIKACE","KATEGORIE", "KOLEJNOST", "ROZCHODNOST", "geometry"))
+
 
 context("chráněná území")
 
@@ -253,7 +325,11 @@ expect_s3_class(chr_uzemi(), "sf")
 
 expect_equal(nrow(chr_uzemi()), 36)
 
-expect_equal(st_crs(chr_uzemi())$epsg, 4326)
+expect_equal(st_crs(chr_uzemi())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(chr_uzemi()), c("TYP", "NAZEV", "geometry"))
+
 
 context("lesy")
 
@@ -271,7 +347,11 @@ expect_s3_class(lesy(), "sf")
 
 expect_equal(nrow(lesy()), 2366)
 
-expect_equal(st_crs(lesy())$epsg, 4326)
+expect_equal(st_crs(lesy())$input, "EPSG:4326")
+
+# sloupce se nerozbily...
+expect_equal(colnames(lesy()), c("geometry"))
+
 
 context("faunistické čtverce")
 
@@ -286,24 +366,21 @@ expect_equal(nrow(KFME_grid("high")), 4 * 26 * 42) # čtverce jsou všechny
 expect_equal(KFME_grid("low")$ctverec %>% unique() %>% length(), 26 * 42) # názvy jsou unikátní
 expect_equal(KFME_grid("high")$ctverec %>% unique() %>% length(), 4 * 26 * 42) # názvy jsou unikátní
 
-expect_equal(st_crs(KFME_grid())$epsg, 4326)
-expect_equal(st_crs(KFME_grid("high"))$epsg, 4326)
-expect_equal(st_crs(KFME_grid("low"))$epsg, 4326)
+expect_equal(st_crs(KFME_grid())$input, "EPSG:4326")
+expect_equal(st_crs(KFME_grid("high"))$input, "EPSG:4326")
+expect_equal(st_crs(KFME_grid("low"))$input, "EPSG:4326")
 
 expect_error(KFME_grid("bflm")) # neznámé rozlišení - očekávám high(default) / low
 
 telc <- geocode("Telč") %>% # známý bod Telč
   filter(typ == "Obec")
 
-
 hrcava <- geocode("Hrčava") %>% # známý bod Hrčava
   filter(typ == "Obec")
 
-
 cernousy <- geocode("Černousy") %>% # známý bod Černousy
   filter(typ == "Obec")
 
-
 expect_equal(sf::st_intersection(KFME_grid("low"), telc)$ctverec, 6858) # bod Telč je ve velkém čtverci 6858
 expect_equal(sf::st_intersection(KFME_grid("high"), telc)$ctverec, "6858b") # bod Telč je v malém čtverci 6858b
 
@@ -313,6 +390,7 @@ expect_equal(sf::st_intersection(KFME_grid("high"), hrcava)$ctverec, "6479c") #
 expect_equal(sf::st_intersection(KFME_grid("low"), cernousy)$ctverec, 4956) # bod Černousy je ve velkém čtverci 4956
 expect_equal(sf::st_intersection(KFME_grid("high"), cernousy)$ctverec, "4956c") # bod Černousy je v malém čtverci 4956c
 
+
 context("reliéf")
 
 Sys.setenv("NETWORK_UP" = FALSE)
@@ -344,6 +422,7 @@ expect_equal(projection(crs(vyskopis("rayshaded"))), "+proj=longlat +ellps=WGS84
 # očekávaná chyba
 expect_error(vyskopis("bflm")) # neznámé rozlišení - očekávám actual / rayshaded
 
+
 context("integrace")
 
 obec_praha <- obce_body() %>% # bod Praha (určitě správně)
